@@ -63,6 +63,14 @@ class Plugin(plugin.PluginBase):
             ohostedcons.CoreEnv.REQUIREMENTS_CHECK_ENABLED,
             True
         )
+        self.environment.setdefault(
+            ohostedcons.NetworkEnv.FORCE_IPV4,
+            False
+        )
+        self.environment.setdefault(
+            ohostedcons.NetworkEnv.FORCE_IPV6,
+            False
+        )
 
     @plugin.event(
         stage=plugin.Stages.STAGE_SETUP,
@@ -245,9 +253,6 @@ class Plugin(plugin.PluginBase):
             'he_root_ssh_pubkey': self.environment[
                 ohostedcons.CloudInit.ROOT_SSH_PUBKEY
             ],
-            'he_host_ip': self.environment[
-                ohostedcons.CloudInit.HOST_IP
-            ],
             'he_root_ssh_access': self.environment[
                 ohostedcons.CloudInit.ROOT_SSH_ACCESS
             ].lower(),
@@ -277,6 +282,12 @@ class Plugin(plugin.PluginBase):
             ],
             'he_memory_requirements_check_enabled': self.environment[
                 ohostedcons.CoreEnv.MEM_REQUIREMENTS_CHECK_ENABLED
+            ],
+            'he_force_ip4': self.environment[
+                ohostedcons.NetworkEnv.FORCE_IPV4
+            ],
+            'he_force_ip6': self.environment[
+                ohostedcons.NetworkEnv.FORCE_IPV6
             ]
         }
         inventory_source = 'localhost,{fqdn}'.format(
@@ -288,7 +299,7 @@ class Plugin(plugin.PluginBase):
         self.initial_clean_up(bootstrap_vars, inventory_source)
 
         ah = ansible_utils.AnsibleHelper(
-            playbook_name=ohostedcons.FileLocations.HE_AP_BOOTSTRAP_LOCAL_VM,
+            tags=ohostedcons.Const.HE_TAG_BOOTSTRAP_LOCAL_VM,
             extra_vars=bootstrap_vars,
             inventory_source=inventory_source,
         )
@@ -322,7 +333,7 @@ class Plugin(plugin.PluginBase):
 
     def initial_clean_up(self, bootstrap_vars, inventory_source):
         ah = ansible_utils.AnsibleHelper(
-            playbook_name=ohostedcons.FileLocations.HE_AP_INITIAL_CLEAN,
+            tags=ohostedcons.Const.HE_TAG_INITIAL_CLEAN,
             extra_vars=bootstrap_vars,
             inventory_source=inventory_source,
         )
@@ -335,7 +346,7 @@ class Plugin(plugin.PluginBase):
     )
     def _cleanup(self):
         ah = ansible_utils.AnsibleHelper(
-            playbook_name=ohostedcons.FileLocations.HE_AP_FINAL_CLEAN,
+            tags=ohostedcons.Const.HE_TAG_FINAL_CLEAN,
             extra_vars={
                 'he_local_vm_dir': self.environment[
                     ohostedcons.CoreEnv.LOCAL_VM_DIR
